@@ -5,10 +5,11 @@ import (
 	"time"
 
 	humanize "github.com/dustin/go-humanize"
-	"github.com/git-town/git-town/v18/internal/cli/dialog/components"
-	"github.com/git-town/git-town/v18/internal/cli/dialog/components/list"
-	"github.com/git-town/git-town/v18/internal/git/gitdomain"
-	"github.com/git-town/git-town/v18/internal/messages"
+	"github.com/git-town/git-town/v22/internal/cli/dialog/dialogcomponents"
+	"github.com/git-town/git-town/v22/internal/cli/dialog/dialogcomponents/list"
+	"github.com/git-town/git-town/v22/internal/cli/dialog/dialogdomain"
+	"github.com/git-town/git-town/v22/internal/git/gitdomain"
+	"github.com/git-town/git-town/v22/internal/messages"
 )
 
 const (
@@ -32,10 +33,11 @@ const (
 	ResponseQuit     = Response("quit")     // quit the program
 	ResponseSkip     = Response("skip")     // continue the unfinished run state by skipping the current branch
 	ResponseUndo     = Response("undo")     // undo the unfinished run state
+	ResponseBoth     = Response("both")     // continue the old runstate and run the new program
 )
 
 // AskHowToHandleUnfinishedRunState prompts the user for how to handle the unfinished run state.
-func AskHowToHandleUnfinishedRunState(command string, endBranch gitdomain.LocalBranchName, endTime time.Time, canSkip bool, dialogTestInput components.TestInput) (Response, bool, error) {
+func AskHowToHandleUnfinishedRunState(command string, endBranch gitdomain.LocalBranchName, endTime time.Time, canSkip bool, input dialogcomponents.Inputs) (Response, dialogdomain.Exit, error) {
 	entries := list.Entries[Response]{
 		{
 			Data: ResponseQuit,
@@ -61,8 +63,12 @@ func AskHowToHandleUnfinishedRunState(command string, endBranch gitdomain.LocalB
 			Data: ResponseDiscard,
 			Text: messages.UnfinishedRunStateDiscard,
 		},
+		list.Entry[Response]{
+			Data: ResponseBoth,
+			Text: fmt.Sprintf(messages.UnfinishedRunStateBoth, command),
+		},
 	)
-	selection, aborted, err := components.RadioList(entries, 0, unfinishedRunstateTitle, fmt.Sprintf(unfinishedRunstateHelp, command, endBranch, humanize.Time(endTime)), dialogTestInput)
-	fmt.Printf(messages.UnfinishedCommandHandle, components.FormattedSelection(string(selection), aborted))
-	return selection, aborted, err
+	selection, exit, err := dialogcomponents.RadioList(entries, 0, unfinishedRunstateTitle, fmt.Sprintf(unfinishedRunstateHelp, command, endBranch, humanize.Time(endTime)), input, "unfinished-runstate")
+	fmt.Printf(messages.UnfinishedCommandHandle, dialogcomponents.FormattedSelection(string(selection), exit))
+	return selection, exit, err
 }
