@@ -1,7 +1,7 @@
 package flags
 
 import (
-	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v22/internal/config/configdomain"
 	"github.com/spf13/cobra"
 )
 
@@ -13,8 +13,7 @@ func All(desc string) (AddFunc, ReadAllFlagFunc) {
 		cmd.Flags().BoolP(allLong, "a", false, desc)
 	}
 	readFlag := func(cmd *cobra.Command) (configdomain.AllBranches, error) {
-		value, err := cmd.Flags().GetBool(allLong)
-		return configdomain.AllBranches(value), err
+		return readBoolFlag[configdomain.AllBranches](cmd.Flags(), allLong)
 	}
 	return addFlag, readFlag
 }
