@@ -1,7 +1,7 @@
 package flags
 
 import (
-	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v22/internal/config/configdomain"
 	"github.com/spf13/cobra"
 )
 
@@ -13,8 +13,7 @@ func Beam() (AddFunc, ReadBeamFlagFunc) {
 		cmd.Flags().BoolP(beamLong, "b", false, "beam some commits from this branch to the new branch")
 	}
 	readFlag := func(cmd *cobra.Command) (configdomain.Beam, error) {
-		value, err := cmd.Flags().GetBool(beamLong)
-		return configdomain.Beam(value), err
+		return readBoolFlag[configdomain.Beam](cmd.Flags(), beamLong)
 	}
 	return addFlag, readFlag
 }
