@@ -1,7 +1,7 @@
 package flags
 
 import (
-	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v22/internal/config/configdomain"
 	"github.com/spf13/cobra"
 )
 
@@ -13,8 +13,7 @@ func Force(desc string) (AddFunc, ReadForceFlagFunc) {
 		cmd.Flags().BoolP(forceLong, "f", false, desc)
 	}
 	readFlag := func(cmd *cobra.Command) (configdomain.Force, error) {
-		value, err := cmd.Flags().GetBool(forceLong)
-		return configdomain.Force(value), err
+		return readBoolFlag[configdomain.Force](cmd.Flags(), forceLong)
 	}
 	return addFlag, readFlag
 }
