@@ -1,7 +1,8 @@
 package flags
 
 import (
-	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v22/internal/git/gitdomain"
+	. "github.com/git-town/git-town/v22/pkg/prelude"
 	"github.com/spf13/cobra"
 )
 
@@ -14,12 +15,18 @@ func ProposalBody(short string) (AddFunc, ReadProposalBodyFlagFunc) {
 	addFlag := func(cmd *cobra.Command) {
 		cmd.Flags().StringP(bodyLong, short, "", "provide a body for the proposal")
 	}
-	readFlag := func(cmd *cobra.Command) (gitdomain.ProposalBody, error) {
+	readFlag := func(cmd *cobra.Command) (Option[gitdomain.ProposalBody], error) {
+		if !cmd.Flags().Changed(bodyLong) {
+			return None[gitdomain.ProposalBody](), nil
+		}
 		value, err := cmd.Flags().GetString(bodyLong)
-		return gitdomain.ProposalBody(value), err
+		if err != nil {
+			return None[gitdomain.ProposalBody](), err
+		}
+		return Some(gitdomain.ProposalBody(value)), nil
 	}
 	return addFlag, readFlag
 }
 
 // ReadCommitMessageFlagFunc defines the type signature for helper functions that provide the value a string CLI flag associated with a Cobra command.
-type ReadProposalBodyFlagFunc func(*cobra.Command) (gitdomain.ProposalBody, error)
+type ReadProposalBodyFlagFunc func(*cobra.Command) (Option[gitdomain.ProposalBody], error)
