@@ -1,7 +1,8 @@
 package flags
 
 import (
-	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v22/internal/git/gitdomain"
+	. "github.com/git-town/git-town/v22/pkg/prelude"
 	"github.com/spf13/cobra"
 )
 
@@ -15,12 +16,11 @@ func ProposalTitle() (AddFunc, ReadProposalTitleFlagFunc) {
 	addFlag := func(cmd *cobra.Command) {
 		cmd.Flags().StringP(titleLong, titleShort, "", "provide a title for the proposal")
 	}
-	readFlag := func(cmd *cobra.Command) (gitdomain.ProposalTitle, error) {
-		value, err := cmd.Flags().GetString(titleLong)
-		return gitdomain.ProposalTitle(value), err
+	readFlag := func(cmd *cobra.Command) (Option[gitdomain.ProposalTitle], error) {
+		return readStringOptFlag[gitdomain.ProposalTitle](cmd.Flags(), titleLong)
 	}
 	return addFlag, readFlag
 }
 
 // ReadCommitMessageFlagFunc defines the type signature for helper functions that provide the value a string CLI flag associated with a Cobra command.
-type ReadProposalTitleFlagFunc func(*cobra.Command) (gitdomain.ProposalTitle, error)
+type ReadProposalTitleFlagFunc func(*cobra.Command) (Option[gitdomain.ProposalTitle], error)
