@@ -1,7 +1,7 @@
 package flags
 
 import (
-	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v22/internal/config/configdomain"
 	"github.com/spf13/cobra"
 )
 
@@ -13,8 +13,7 @@ func Propose() (AddFunc, ReadProposeFlagFunc) {
 		cmd.Flags().BoolP(proposeLong, "", false, "propose the new branch")
 	}
 	readFlag := func(cmd *cobra.Command) (configdomain.Propose, error) {
-		value, err := cmd.Flags().GetBool(proposeLong)
-		return configdomain.Propose(value), err
+		return readBoolFlag[configdomain.Propose](cmd.Flags(), proposeLong)
 	}
 	return addFlag, readFlag
 }
