@@ -1,7 +1,7 @@
 package flags
 
 import (
-	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v22/internal/config/configdomain"
 	"github.com/spf13/cobra"
 )
 
@@ -13,8 +13,7 @@ func ShipIntoNonPerennialParent() (AddFunc, ReadShipIntoNonPerennialParentFlagFu
 		cmd.Flags().BoolP(shipIntoNonPerennialParentLong, "p", false, "allow shipping into non-perennial parent")
 	}
 	readFlag := func(cmd *cobra.Command) (configdomain.ShipIntoNonperennialParent, error) {
-		value, err := cmd.Flags().GetBool(shipIntoNonPerennialParentLong)
-		return configdomain.ShipIntoNonperennialParent(value), err
+		return readBoolFlag[configdomain.ShipIntoNonperennialParent](cmd.Flags(), shipIntoNonPerennialParentLong)
 	}
 	return addFlag, readFlag
 }
