@@ -1,8 +1,8 @@
 package flags
 
 import (
-	"github.com/git-town/git-town/v18/internal/config/configdomain"
-	. "github.com/git-town/git-town/v18/pkg/prelude"
+	"github.com/git-town/git-town/v22/internal/config/configdomain"
+	. "github.com/git-town/git-town/v22/pkg/prelude"
 	"github.com/spf13/cobra"
 )
 
@@ -18,15 +18,7 @@ func ShipStrategy() (AddFunc, ReadShipStrategyFunc) {
 		if err != nil {
 			return None[configdomain.ShipStrategy](), err
 		}
-		strategyOpt, err := configdomain.ParseShipStrategy(value)
-		if err != nil {
-			return None[configdomain.ShipStrategy](), err
-		}
-		strategy, hasStrategy := strategyOpt.Get()
-		if !hasStrategy {
-			return None[configdomain.ShipStrategy](), nil
-		}
-		return Some(strategy), nil
+		return configdomain.ParseShipStrategy(value, "--strategy CLI flag")
 	}
 	return addFlag, readFlag
 }
