@@ -1,7 +1,7 @@
 package flags
 
 import (
-	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v22/internal/config/configdomain"
 	"github.com/spf13/cobra"
 )
 
@@ -13,8 +13,7 @@ func Stack(description string) (AddFunc, ReadStackFlagFunc) {
 		cmd.Flags().BoolP(stackLong, "s", false, description)
 	}
 	readFlag := func(cmd *cobra.Command) (configdomain.FullStack, error) {
-		value, err := cmd.Flags().GetBool(stackLong)
-		return configdomain.FullStack(value), err
+		return readBoolFlag[configdomain.FullStack](cmd.Flags(), stackLong)
 	}
 	return addFlag, readFlag
 }
