@@ -1,7 +1,8 @@
 package flags
 
 import (
-	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v22/internal/config/configdomain"
+	. "github.com/git-town/git-town/v22/pkg/prelude"
 	"github.com/spf13/cobra"
 )
 
@@ -15,12 +16,11 @@ func Verbose() (AddFunc, ReadVerboseFlagFunc) {
 	addFlag := func(cmd *cobra.Command) {
 		cmd.Flags().BoolP(verboseLong, verboseShort, false, "display all Git commands run under the hood")
 	}
-	readFlag := func(cmd *cobra.Command) (configdomain.Verbose, error) {
-		value, err := cmd.Flags().GetBool(verboseLong)
-		return configdomain.Verbose(value), err
+	readFlag := func(cmd *cobra.Command) (Option[configdomain.Verbose], error) {
+		return readBoolOptFlag[configdomain.Verbose](cmd.Flags(), verboseLong)
 	}
 	return addFlag, readFlag
 }
 
 // ReadVerboseFlagFunc is the type signature for the function that reads the "verbose" flag from the args to the given Cobra command.
-type ReadVerboseFlagFunc func(*cobra.Command) (configdomain.Verbose, error)
+type ReadVerboseFlagFunc func(*cobra.Command) (Option[configdomain.Verbose], error)
