@@ -3,8 +3,8 @@ package format_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v18/internal/cli/format"
-	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v22/internal/cli/format"
+	"github.com/git-town/git-town/v22/internal/forge/forgedomain"
 	"github.com/shoenig/test/must"
 )
 
@@ -15,7 +15,7 @@ func TestOptionalStringerSetting(t *testing.T) {
 		"":         "(not set)",
 	}
 	for give, want := range tests {
-		option := configdomain.ParseGitHubToken(give)
+		option := forgedomain.ParseGitHubToken(give)
 		have := format.OptionalStringerSetting(option)
 		must.EqOp(t, want, have)
 	}
