@@ -3,10 +3,10 @@ package print
 import (
 	"fmt"
 
-	"github.com/git-town/git-town/v18/internal/cli/colors"
-	"github.com/git-town/git-town/v18/internal/config/configdomain"
-	"github.com/git-town/git-town/v18/internal/gohacks"
-	"github.com/git-town/git-town/v18/internal/messages"
+	"github.com/git-town/git-town/v22/internal/config/configdomain"
+	"github.com/git-town/git-town/v22/internal/gohacks"
+	"github.com/git-town/git-town/v22/internal/messages"
+	"github.com/git-town/git-town/v22/pkg/colors"
 )
 
 func Footer(verbose configdomain.Verbose, commandsCount gohacks.Counter, finalMessages []string) {
