@@ -4,14 +4,18 @@ import (
 	"errors"
 	"fmt"
 
-	"github.com/git-town/git-town/v18/internal/cli/flags"
-	"github.com/git-town/git-town/v18/internal/cmd/cmdhelpers"
-	"github.com/git-town/git-town/v18/internal/config/configdomain"
-	"github.com/git-town/git-town/v18/internal/execute"
-	"github.com/git-town/git-town/v18/internal/git/gitdomain"
-	"github.com/git-town/git-town/v18/internal/messages"
-	configInterpreter "github.com/git-town/git-town/v18/internal/vm/interpreter/config"
-	. "github.com/git-town/git-town/v18/pkg/prelude"
+	"github.com/git-town/git-town/v22/internal/cli/flags"
+	"github.com/git-town/git-town/v22/internal/cmd/cmdhelpers"
+	"github.com/git-town/git-town/v22/internal/config"
+	"github.com/git-town/git-town/v22/internal/config/cliconfig"
+	"github.com/git-town/git-town/v22/internal/config/configdomain"
+	"github.com/git-town/git-town/v22/internal/config/gitconfig"
+	"github.com/git-town/git-town/v22/internal/execute"
+	"github.com/git-town/git-town/v22/internal/git/gitdomain"
+	"github.com/git-town/git-town/v22/internal/gohacks/mapstools"
+	"github.com/git-town/git-town/v22/internal/messages"
+	"github.com/git-town/git-town/v22/internal/vm/interpreter/configinterpreter"
+	. "github.com/git-town/git-town/v22/pkg/prelude"
 	"github.com/spf13/cobra"
 )
 
@@ -46,21 +50,32 @@ func contributeCmd() *cobra.Command {
 			if err != nil {
 				return err
 			}
-			return executeContribute(args, verbose)
+			cliConfig := cliconfig.New(cliconfig.NewArgs{
+				AutoResolve:  None[configdomain.AutoResolve](),
+				AutoSync:     None[configdomain.AutoSync](),
+				Detached:     Some(configdomain.Detached(true)),
+				DisplayTypes: None[configdomain.DisplayTypes](),
+				DryRun:       None[configdomain.DryRun](),
+				Order:        None[configdomain.Order](),
+				PushBranches: None[configdomain.PushBranches](),
+				Stash:        None[configdomain.Stash](),
+				Verbose:      verbose,
+			})
+			return executeContribute(args, cliConfig)
 		},
 	}
 	addVerboseFlag(&cmd)
 	return &cmd
 }
 
-func executeContribute(args []string, verbose configdomain.Verbose) error {
+func executeContribute(args []string, cliConfig configdomain.PartialConfig) error {
 	repo, err := execute.OpenRepo(execute.OpenRepoArgs{
-		DryRun:           false,
+		CliConfig:        cliConfig,
+		IgnoreUnknown:    false,
 		PrintBranchNames: false,
 		PrintCommands:    true,
 		ValidateGitRepo:  true,
 		ValidateIsOnline: false,
-		Verbose:          verbose,
 	})
 	if err != nil {
 		return err
@@ -72,8 +87,8 @@ func executeContribute(args []string, verbose configdomain.Verbose) error {
 	if err = validateContributeData(data, repo); err != nil {
 		return err
 	}
-	branchNames := data.branchesToMark.Keys()
-	if err = repo.UnvalidatedConfig.NormalConfig.SetBranchTypeOverride(configdomain.BranchTypeContributionBranch, branchNames...); err != nil {
+	branchNames := data.branchesToMakeContribution.Keys()
+	if err = gitconfig.SetBranchTypeOverride(repo.Backend, configdomain.BranchTypeContributionBranch, branchNames...); err != nil {
 		return err
 	}
 	printContributeBranches(branchNames)
@@ -82,7 +97,7 @@ func executeContribute(args []string, verbose configdomain.Verbose) error {
 			return err
 		}
 	}
-	return configInterpreter.Finished(configInterpreter.FinishedArgs{
+	return configinterpreter.Finished(configinterpreter.FinishedArgs{
 		Backend:               repo.Backend,
 		BeginBranchesSnapshot: Some(data.beginBranchesSnapshot),
 		BeginConfigSnapshot:   repo.ConfigSnapshot,
@@ -91,21 +106,21 @@ func executeContribute(args []string, verbose configdomain.Verbose) error {
 		FinalMessages:         repo.FinalMessages,
 		Git:                   repo.Git,
 		RootDir:               repo.RootDir,
-		TouchedBranches:       data.branchesToMark.Keys().BranchNames(),
-		Verbose:               verbose,
+		TouchedBranches:       data.branchesToMakeContribution.Keys().BranchNames(),
+		Verbose:               repo.UnvalidatedConfig.NormalConfig.Verbose,
 	})
 }
 
 type contributeData struct {
-	beginBranchesSnapshot gitdomain.BranchesSnapshot
-	branchInfos           gitdomain.BranchInfos
-	branchToCheckout      Option[gitdomain.LocalBranchName]
-	branchesToMark        configdomain.BranchesAndTypes
+	beginBranchesSnapshot      gitdomain.BranchesSnapshot
+	branchInfos                gitdomain.BranchInfos
+	branchToCheckout           Option[gitdomain.LocalBranchName]
+	branchesToMakeContribution configdomain.BranchesAndTypes
 }
 
 func printContributeBranches(branches gitdomain.LocalBranchNames) {
 	for _, branch := range branches {
-		fmt.Printf(messages.ContributeBranchIsNowContribution, branch)
+		fmt.Printf(messages.BranchIsNowContribution, branch)
 	}
 }
 
@@ -114,32 +129,35 @@ func determineContributeData(args []string, repo execute.OpenRepoResult) (contri
 	if err != nil {
 		return contributeData{}, err
 	}
-	branchesToMakeContribution, branchToCheckout, err := execute.BranchesToMark(args, branchesSnapshot, repo.UnvalidatedConfig)
+	if branchesSnapshot.DetachedHead {
+		return contributeData{}, errors.New(messages.ContributeDetachedHead)
+	}
+	branchesToMakeContribution, branchToCheckout, err := config.BranchesToMark(args, branchesSnapshot, repo.UnvalidatedConfig)
 	return contributeData{
-		beginBranchesSnapshot: branchesSnapshot,
-		branchInfos:           branchesSnapshot.Branches,
-		branchToCheckout:      branchToCheckout,
-		branchesToMark:        branchesToMakeContribution,
+		beginBranchesSnapshot:      branchesSnapshot,
+		branchInfos:                branchesSnapshot.Branches,
+		branchToCheckout:           branchToCheckout,
+		branchesToMakeContribution: branchesToMakeContribution,
 	}, err
 }
 
 func validateContributeData(data contributeData, repo execute.OpenRepoResult) error {
-	for branchName, branchType := range data.branchesToMark {
+	for branchName, branchType := range mapstools.SortedKeyValues(data.branchesToMakeContribution) {
 		switch branchType {
 		case configdomain.BranchTypeMainBranch:
 			return errors.New(messages.MainBranchCannotMakeContribution)
 		case configdomain.BranchTypePerennialBranch:
 			return errors.New(messages.PerennialBranchCannotMakeContribution)
 		case configdomain.BranchTypeContributionBranch:
-			return fmt.Errorf(messages.BranchIsAlreadyContribution, branchName)
+			repo.FinalMessages.Add(fmt.Sprintf(messages.BranchIsAlreadyContribution, branchName))
 		case
 			configdomain.BranchTypeFeatureBranch,
 			configdomain.BranchTypeObservedBranch,
 			configdomain.BranchTypeParkedBranch,
 			configdomain.BranchTypePrototypeBranch:
 		}
-		hasLocalBranch := data.branchInfos.HasLocalBranch(branchName)
-		hasRemoteBranch := data.branchInfos.HasMatchingTrackingBranchFor(branchName, repo.UnvalidatedConfig.NormalConfig.DevRemote)
+		hasLocalBranch := data.beginBranchesSnapshot.Branches.HasLocalBranch(branchName)
+		hasRemoteBranch := data.beginBranchesSnapshot.Branches.HasMatchingTrackingBranchFor(branchName, repo.UnvalidatedConfig.NormalConfig.DevRemote)
 		if !hasLocalBranch && !hasRemoteBranch {
 			return fmt.Errorf(messages.BranchDoesntExist, branchName)
 		}
