@@ -4,14 +4,18 @@ import (
 	"errors"
 	"fmt"
 
-	"github.com/git-town/git-town/v18/internal/cli/flags"
-	"github.com/git-town/git-town/v18/internal/cmd/cmdhelpers"
-	"github.com/git-town/git-town/v18/internal/config/configdomain"
-	"github.com/git-town/git-town/v18/internal/execute"
-	"github.com/git-town/git-town/v18/internal/git/gitdomain"
-	"github.com/git-town/git-town/v18/internal/messages"
-	interpreterConfig "github.com/git-town/git-town/v18/internal/vm/interpreter/config"
-	. "github.com/git-town/git-town/v18/pkg/prelude"
+	"github.com/git-town/git-town/v22/internal/cli/flags"
+	"github.com/git-town/git-town/v22/internal/cmd/cmdhelpers"
+	"github.com/git-town/git-town/v22/internal/config"
+	"github.com/git-town/git-town/v22/internal/config/cliconfig"
+	"github.com/git-town/git-town/v22/internal/config/configdomain"
+	"github.com/git-town/git-town/v22/internal/config/gitconfig"
+	"github.com/git-town/git-town/v22/internal/execute"
+	"github.com/git-town/git-town/v22/internal/git/gitdomain"
+	"github.com/git-town/git-town/v22/internal/gohacks/mapstools"
+	"github.com/git-town/git-town/v22/internal/messages"
+	"github.com/git-town/git-town/v22/internal/vm/interpreter/configinterpreter"
+	. "github.com/git-town/git-town/v22/pkg/prelude"
 	"github.com/spf13/cobra"
 )
 
@@ -42,21 +46,32 @@ func prototypeCmd() *cobra.Command {
 			if err != nil {
 				return err
 			}
-			return executePrototype(args, verbose)
+			cliConfig := cliconfig.New(cliconfig.NewArgs{
+				AutoResolve:  None[configdomain.AutoResolve](),
+				AutoSync:     None[configdomain.AutoSync](),
+				Detached:     None[configdomain.Detached](),
+				DisplayTypes: None[configdomain.DisplayTypes](),
+				DryRun:       None[configdomain.DryRun](),
+				Order:        None[configdomain.Order](),
+				PushBranches: None[configdomain.PushBranches](),
+				Stash:        None[configdomain.Stash](),
+				Verbose:      verbose,
+			})
+			return executePrototype(args, cliConfig)
 		},
 	}
 	addVerboseFlag(&cmd)
 	return &cmd
 }
 
-func executePrototype(args []string, verbose configdomain.Verbose) error {
+func executePrototype(args []string, cliConfig configdomain.PartialConfig) error {
 	repo, err := execute.OpenRepo(execute.OpenRepoArgs{
-		DryRun:           false,
+		CliConfig:        cliConfig,
+		IgnoreUnknown:    false,
 		PrintBranchNames: true,
 		PrintCommands:    true,
 		ValidateGitRepo:  true,
 		ValidateIsOnline: false,
-		Verbose:          verbose,
 	})
 	if err != nil {
 		return err
@@ -69,7 +84,7 @@ func executePrototype(args []string, verbose configdomain.Verbose) error {
 		return err
 	}
 	branchNames := data.branchesToPrototype.Keys()
-	if err = repo.UnvalidatedConfig.NormalConfig.SetBranchTypeOverride(configdomain.BranchTypePrototypeBranch, branchNames...); err != nil {
+	if err = gitconfig.SetBranchTypeOverride(repo.Backend, configdomain.BranchTypePrototypeBranch, branchNames...); err != nil {
 		return err
 	}
 	if checkout, hasCheckout := data.checkout.Get(); hasCheckout {
@@ -78,7 +93,7 @@ func executePrototype(args []string, verbose configdomain.Verbose) error {
 		}
 	}
 	printPrototypeBranches(branchNames)
-	return interpreterConfig.Finished(interpreterConfig.FinishedArgs{
+	return configinterpreter.Finished(configinterpreter.FinishedArgs{
 		Backend:               repo.Backend,
 		BeginBranchesSnapshot: Some(data.branchesSnapshot),
 		BeginConfigSnapshot:   repo.ConfigSnapshot,
@@ -88,7 +103,7 @@ func executePrototype(args []string, verbose configdomain.Verbose) error {
 		Git:                   repo.Git,
 		RootDir:               repo.RootDir,
 		TouchedBranches:       branchNames.BranchNames(),
-		Verbose:               verbose,
+		Verbose:               repo.UnvalidatedConfig.NormalConfig.Verbose,
 	})
 }
 
@@ -101,7 +116,7 @@ type prototypeData struct {
 
 func printPrototypeBranches(branches gitdomain.LocalBranchNames) {
 	for _, branch := range branches {
-		fmt.Printf(messages.PrototypeBranchIsNowPrototype, branch)
+		fmt.Printf(messages.BranchIsNowPrototype, branch)
 	}
 }
 
@@ -110,7 +125,10 @@ func determinePrototypeData(args []string, repo execute.OpenRepoResult) (prototy
 	if err != nil {
 		return prototypeData{}, err
 	}
-	branchesToPrototype, branchToCheckout, err := execute.BranchesToMark(args, branchesSnapshot, repo.UnvalidatedConfig)
+	if branchesSnapshot.DetachedHead {
+		return prototypeData{}, errors.New(messages.PrototypeDetachedHead)
+	}
+	branchesToPrototype, branchToCheckout, err := config.BranchesToMark(args, branchesSnapshot, repo.UnvalidatedConfig)
 	return prototypeData{
 		branchInfos:         branchesSnapshot.Branches,
 		branchesSnapshot:    branchesSnapshot,
@@ -120,8 +138,8 @@ func determinePrototypeData(args []string, repo execute.OpenRepoResult) (prototy
 }
 
 func validatePrototypeData(data prototypeData, repo execute.OpenRepoResult) error {
-	for branchName, branchType := range data.branchesToPrototype {
-		if !data.branchInfos.HasLocalBranch(branchName) && !data.branchInfos.HasMatchingTrackingBranchFor(branchName, repo.UnvalidatedConfig.NormalConfig.DevRemote) {
+	for branchName, branchType := range mapstools.SortedKeyValues(data.branchesToPrototype) {
+		if !data.branchesSnapshot.Branches.HasLocalBranch(branchName) && !data.branchesSnapshot.Branches.HasMatchingTrackingBranchFor(branchName, repo.UnvalidatedConfig.NormalConfig.DevRemote) {
 			return fmt.Errorf(messages.BranchDoesntExist, branchName)
 		}
 		switch branchType {
@@ -130,14 +148,13 @@ func validatePrototypeData(data prototypeData, repo execute.OpenRepoResult) erro
 		case configdomain.BranchTypePerennialBranch:
 			return errors.New(messages.PerennialBranchCannotPrototype)
 		case configdomain.BranchTypePrototypeBranch:
-			return fmt.Errorf(messages.BranchIsAlreadyPrototype, branchName)
+			repo.FinalMessages.Add(fmt.Sprintf(messages.BranchIsAlreadyPrototype, branchName))
 		case
 			configdomain.BranchTypeFeatureBranch,
 			configdomain.BranchTypeContributionBranch,
 			configdomain.BranchTypeParkedBranch,
 			configdomain.BranchTypeObservedBranch:
-		default:
-			panic("unhandled branch type" + branchType.String())
+			data.branchesToPrototype.Add(branchName, branchType)
 		}
 	}
 	return nil
