@@ -1,15 +1,15 @@
 package sync
 
 import (
-	"github.com/git-town/git-town/v18/internal/config/configdomain"
-	"github.com/git-town/git-town/v18/internal/git/gitdomain"
-	"github.com/git-town/git-town/v18/internal/vm/opcodes"
-	"github.com/git-town/git-town/v18/internal/vm/program"
-	. "github.com/git-town/git-town/v18/pkg/prelude"
+	"github.com/git-town/git-town/v22/internal/config/configdomain"
+	"github.com/git-town/git-town/v22/internal/git/gitdomain"
+	"github.com/git-town/git-town/v22/internal/vm/opcodes"
+	"github.com/git-town/git-town/v22/internal/vm/program"
+	. "github.com/git-town/git-town/v22/pkg/prelude"
 )
 
 func RemoveBranchConfiguration(args RemoveBranchConfigurationArgs) {
-	childBranches := args.Lineage.Children(args.Branch)
+	childBranches := args.Lineage.Children(args.Branch, args.Order)
 	for _, child := range childBranches {
 		args.Program.Value.Add(&opcodes.LineageParentSetToGrandParent{Branch: child})
 	}
@@ -19,5 +19,6 @@ func RemoveBranchConfiguration(args RemoveBranchConfigurationArgs) {
 type RemoveBranchConfigurationArgs struct {
 	Branch  gitdomain.LocalBranchName
 	Lineage configdomain.Lineage
+	Order   configdomain.Order
 	Program Mutable[program.Program]
 }
