@@ -1,6 +1,6 @@
 package configdomain
 
-import . "github.com/git-town/git-town/v18/pkg/prelude"
+import . "github.com/git-town/git-town/v22/pkg/prelude"
 
 type AliasableCommands []AliasableCommand
 
@@ -30,6 +30,7 @@ func AllAliasableCommands() AliasableCommands {
 		AliasableCommandCompress,
 		AliasableCommandContribute,
 		AliasableCommandDiffParent,
+		AliasableCommandDown,
 		AliasableCommandHack,
 		AliasableCommandDelete,
 		AliasableCommandObserve,
@@ -41,5 +42,6 @@ func AllAliasableCommands() AliasableCommands {
 		AliasableCommandSetParent,
 		AliasableCommandShip,
 		AliasableCommandSync,
+		AliasableCommandUp,
 	}
 }
