@@ -3,10 +3,6 @@ package configdomain
 // indicates whether a Git Town command should create a prototype branch
 type Beam bool
 
-func (self Beam) IsFalse() bool {
-	return !self.IsTrue()
-}
-
-func (self Beam) IsTrue() bool {
+func (self Beam) ShouldBeam() bool {
 	return bool(self)
 }
