@@ -4,7 +4,8 @@ import (
 	"fmt"
 	"strings"
 
-	. "github.com/git-town/git-town/v18/pkg/prelude"
+	"github.com/git-town/git-town/v22/internal/messages"
+	. "github.com/git-town/git-town/v22/pkg/prelude"
 )
 
 type BranchType string
@@ -31,8 +32,8 @@ func AllBranchTypes() []BranchType {
 	}
 }
 
-func ParseBranchType(text string) (Option[BranchType], error) {
-	if len(text) == 0 || text == "(none)" {
+func ParseBranchType(text string, source string) (Option[BranchType], error) {
+	if len(text) == 0 || text == messages.DialogResultNone {
 		return None[BranchType](), nil
 	}
 	for _, branchType := range AllBranchTypes() {
@@ -40,7 +41,7 @@ func ParseBranchType(text string) (Option[BranchType], error) {
 			return Some(branchType), nil
 		}
 	}
-	return None[BranchType](), fmt.Errorf("unknown branch type: %q", text)
+	return None[BranchType](), fmt.Errorf(messages.DialogResultUnknownBranchType, source, text)
 }
 
 func (self BranchType) MustKnowParent() bool {
