@@ -3,10 +3,9 @@ package configdomain_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v18/internal/config"
-	"github.com/git-town/git-town/v18/internal/config/configdomain"
-	"github.com/git-town/git-town/v18/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v18/pkg/prelude"
+	"github.com/git-town/git-town/v22/internal/config"
+	"github.com/git-town/git-town/v22/internal/config/configdomain"
+	"github.com/git-town/git-town/v22/internal/git/gitdomain"
 	"github.com/shoenig/test/must"
 )
 
@@ -18,10 +17,10 @@ func TestBranchesAndTypes(t *testing.T) {
 		have := configdomain.BranchesAndTypes{}
 		unvalidatedConfig := config.UnvalidatedConfig{
 			UnvalidatedConfig: configdomain.UnvalidatedConfigData{
-				MainBranch: Some(gitdomain.NewLocalBranchName("main")),
+				MainBranch: gitdomain.NewLocalBranchNameOption("main"),
 			},
 		}
-		have.Add("main", &unvalidatedConfig)
+		have.AddTypeFor("main", &unvalidatedConfig)
 		want := map[gitdomain.LocalBranchName]configdomain.BranchType{
 			"main": configdomain.BranchTypeMainBranch,
 		}
@@ -33,12 +32,10 @@ func TestBranchesAndTypes(t *testing.T) {
 		have := configdomain.BranchesAndTypes{}
 		unvalidatedConfig := config.UnvalidatedConfig{
 			UnvalidatedConfig: configdomain.UnvalidatedConfigData{
-				MainBranch: Some(gitdomain.NewLocalBranchName("main")),
+				MainBranch: gitdomain.NewLocalBranchNameOption("main"),
 			},
 			NormalConfig: config.NormalConfig{
-				NormalConfigData: configdomain.NormalConfigData{
-					PerennialBranches: gitdomain.NewLocalBranchNames("perennial"),
-				},
+				PerennialBranches: gitdomain.NewLocalBranchNames("perennial"),
 			},
 		}
 		have.AddMany(gitdomain.NewLocalBranchNames("main", "perennial"), &unvalidatedConfig)
