@@ -2,3 +2,7 @@ package configdomain
 
 // when creating a new branch, whether to commit the currently staged changes into that new branch
 type Commit bool
+
+func (self Commit) ShouldCommit() bool {
+	return bool(self)
+}
