@@ -1,13 +1,21 @@
 package configdomain
 
-import . "github.com/git-town/git-town/v18/pkg/prelude"
+import (
+	"fmt"
+
+	"github.com/git-town/git-town/v22/internal/messages"
+	. "github.com/git-town/git-town/v22/pkg/prelude"
+)
 
 type FeatureRegex struct {
 	VerifiedRegex
 }
 
-func ParseFeatureRegex(value string) (Option[FeatureRegex], error) {
+func ParseFeatureRegex(value string, source string) (Option[FeatureRegex], error) {
 	verifiedRegexOpt, err := ParseRegex(value)
+	if err != nil {
+		return None[FeatureRegex](), fmt.Errorf(messages.CannotParse, source, err)
+	}
 	if verifiedRegex, hasVerifiedRegex := verifiedRegexOpt.Get(); hasVerifiedRegex {
 		return Some(FeatureRegex{VerifiedRegex: verifiedRegex}), err
 	}
