@@ -3,9 +3,9 @@ package configdomain_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v18/internal/config/configdomain"
-	"github.com/git-town/git-town/v18/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v18/pkg/prelude"
+	"github.com/git-town/git-town/v22/internal/config/configdomain"
+	"github.com/git-town/git-town/v22/internal/git/gitdomain"
+	. "github.com/git-town/git-town/v22/pkg/prelude"
 	"github.com/shoenig/test/must"
 )
 
@@ -92,12 +92,23 @@ func TestLineage(t *testing.T) {
 		must.Eq(t, want, have)
 	})
 
+	t.Run("BranchAndAncestorsWithoutRoot", func(t *testing.T) {
+		t.Parallel()
+		lineage := configdomain.NewLineageWith(configdomain.LineageData{
+			one: main,
+			two: one,
+		})
+		have := lineage.BranchAndAncestorsWithoutRoot(two)
+		want := gitdomain.LocalBranchNames{one, two}
+		must.Eq(t, want, have)
+	})
+
 	t.Run("BranchLineageWithoutRoot", func(t *testing.T) {
 		t.Parallel()
 		t.Run("only root exists", func(t *testing.T) {
 			t.Parallel()
-			lineage := configdomain.Lineage{}
-			have := lineage.BranchLineageWithoutRoot(main, gitdomain.LocalBranchNames{main})
+			lineage := configdomain.NewLineage()
+			have := lineage.BranchLineageWithoutRoot(main, gitdomain.LocalBranchNames{main}, configdomain.OrderAsc)
 			want := gitdomain.LocalBranchNames{}
 			must.Eq(t, want, have)
 		})
@@ -106,7 +117,7 @@ func TestLineage(t *testing.T) {
 			lineage := configdomain.NewLineageWith(configdomain.LineageData{
 				one: main,
 			})
-			have := lineage.BranchLineageWithoutRoot(one, gitdomain.LocalBranchNames{main})
+			have := lineage.BranchLineageWithoutRoot(one, gitdomain.LocalBranchNames{main}, configdomain.OrderAsc)
 			want := gitdomain.LocalBranchNames{one}
 			must.Eq(t, want, have)
 		})
@@ -119,24 +130,24 @@ func TestLineage(t *testing.T) {
 			want := gitdomain.LocalBranchNames{one, two}
 			t.Run("given root", func(t *testing.T) {
 				t.Parallel()
-				have := lineage.BranchLineageWithoutRoot(main, gitdomain.LocalBranchNames{main})
+				have := lineage.BranchLineageWithoutRoot(main, gitdomain.LocalBranchNames{main}, configdomain.OrderAsc)
 				must.Eq(t, want, have)
 			})
 			t.Run("given middle branch", func(t *testing.T) {
 				t.Parallel()
-				have := lineage.BranchLineageWithoutRoot(one, gitdomain.LocalBranchNames{main})
+				have := lineage.BranchLineageWithoutRoot(one, gitdomain.LocalBranchNames{main}, configdomain.OrderAsc)
 				must.Eq(t, want, have)
 			})
 			t.Run("given leaf branch", func(t *testing.T) {
 				t.Parallel()
-				have := lineage.BranchLineageWithoutRoot(two, gitdomain.LocalBranchNames{main})
+				have := lineage.BranchLineageWithoutRoot(two, gitdomain.LocalBranchNames{main}, configdomain.OrderAsc)
 				must.Eq(t, want, have)
 			})
 		})
 		t.Run("branch without an ancestor", func(t *testing.T) {
 			t.Parallel()
-			lineage := configdomain.Lineage{}
-			have := lineage.BranchLineageWithoutRoot(one, gitdomain.LocalBranchNames{main})
+			lineage := configdomain.NewLineage()
+			have := lineage.BranchLineageWithoutRoot(one, gitdomain.LocalBranchNames{main}, configdomain.OrderAsc)
 			want := gitdomain.LocalBranchNames{one}
 			must.Eq(t, want, have)
 		})
@@ -164,7 +175,7 @@ func TestLineage(t *testing.T) {
 				three: two,
 			})
 			give := gitdomain.LocalBranchNames{two, one}
-			have := lineage.BranchesAndAncestors(give)
+			have := lineage.BranchesAndAncestors(give, configdomain.OrderAsc)
 			want := gitdomain.LocalBranchNames{main, one, two}
 			must.Eq(t, want, have)
 		})
@@ -176,7 +187,7 @@ func TestLineage(t *testing.T) {
 				three: two,
 			})
 			give := gitdomain.LocalBranchNames{one, two, main, three}
-			have := lineage.BranchesAndAncestors(give)
+			have := lineage.BranchesAndAncestors(give, configdomain.OrderAsc)
 			want := gitdomain.LocalBranchNames{main, one, two, three}
 			must.Eq(t, want, have)
 		})
@@ -188,7 +199,7 @@ func TestLineage(t *testing.T) {
 				three: two,
 			})
 			give := gitdomain.LocalBranchNames{three}
-			have := lineage.BranchesAndAncestors(give)
+			have := lineage.BranchesAndAncestors(give, configdomain.OrderAsc)
 			want := gitdomain.LocalBranchNames{main, one, two, three}
 			must.Eq(t, want, have)
 		})
@@ -206,7 +217,7 @@ func TestLineage(t *testing.T) {
 				third:  second,
 			})
 			give := gitdomain.LocalBranchNames{main, first, one, second, third, three, two}
-			have := lineage.BranchesAndAncestors(give)
+			have := lineage.BranchesAndAncestors(give, configdomain.OrderAsc)
 			want := gitdomain.LocalBranchNames{main, first, second, third, one, two, three}
 			must.Eq(t, want, have)
 		})
@@ -235,7 +246,7 @@ func TestLineage(t *testing.T) {
 
 	t.Run("Children", func(t *testing.T) {
 		t.Parallel()
-		t.Run("provides all children of the given branch, ordered alphabetically", func(t *testing.T) {
+		t.Run("provides all children of the given branch, ordered ascending", func(t *testing.T) {
 			t.Parallel()
 			twoA := gitdomain.NewLocalBranchName("twoA")
 			twoB := gitdomain.NewLocalBranchName("twoB")
@@ -243,24 +254,36 @@ func TestLineage(t *testing.T) {
 				twoA: one,
 				twoB: one,
 			})
-			have := lineage.Children(one)
+			have := lineage.Children(one, configdomain.OrderAsc)
 			want := gitdomain.LocalBranchNames{twoA, twoB}
 			must.Eq(t, want, have)
 		})
+		t.Run("provides all children of the given branch, ordered descending", func(t *testing.T) {
+			t.Parallel()
+			twoA := gitdomain.NewLocalBranchName("twoA")
+			twoB := gitdomain.NewLocalBranchName("twoB")
+			lineage := configdomain.NewLineageWith(configdomain.LineageData{
+				twoA: one,
+				twoB: one,
+			})
+			have := lineage.Children(one, configdomain.OrderDesc)
+			want := gitdomain.LocalBranchNames{twoB, twoA}
+			must.Eq(t, want, have)
+		})
 		t.Run("provides only the immediate children, i.e. no grandchildren", func(t *testing.T) {
 			t.Parallel()
 			lineage := configdomain.NewLineageWith(configdomain.LineageData{
 				two:   one,
 				three: two,
 			})
-			have := lineage.Children(one)
+			have := lineage.Children(one, configdomain.OrderAsc)
 			want := gitdomain.LocalBranchNames{two}
 			must.Eq(t, want, have)
 		})
 		t.Run("empty", func(t *testing.T) {
 			t.Parallel()
-			lineage := configdomain.Lineage{}
-			have := lineage.Children(one)
+			lineage := configdomain.NewLineage()
+			have := lineage.Children(one, configdomain.OrderAsc)
 			want := gitdomain.LocalBranchNames{}
 			must.Eq(t, want, have)
 		})
@@ -276,7 +299,7 @@ func TestLineage(t *testing.T) {
 				branch: main,
 				other:  main,
 			})
-			have := lineage.Descendants(branch)
+			have := lineage.Descendants(branch, configdomain.OrderAsc)
 			want := gitdomain.LocalBranchNames{}
 			must.Eq(t, want, have)
 		})
@@ -292,7 +315,7 @@ func TestLineage(t *testing.T) {
 				child2: branch,
 				other:  main,
 			})
-			have := lineage.Descendants(branch)
+			have := lineage.Descendants(branch, configdomain.OrderAsc)
 			want := gitdomain.LocalBranchNames{child1, child2}
 			must.Eq(t, want, have)
 		})
@@ -316,7 +339,7 @@ func TestLineage(t *testing.T) {
 				child2b: child2,
 				other:   main,
 			})
-			have := lineage.Descendants(branch)
+			have := lineage.Descendants(branch, configdomain.OrderAsc)
 			want := gitdomain.LocalBranchNames{child1, child1a, child1b, child2, child2a, child2b}
 			must.Eq(t, want, have)
 		})
@@ -385,7 +408,7 @@ func TestLineage(t *testing.T) {
 		})
 		t.Run("has no parent", func(t *testing.T) {
 			t.Parallel()
-			lineage := configdomain.Lineage{}
+			lineage := configdomain.NewLineage()
 			must.False(t, lineage.HasParents(main))
 		})
 	})
@@ -434,48 +457,6 @@ func TestLineage(t *testing.T) {
 		})
 	})
 
-	t.Run("LatestAncestor", func(t *testing.T) {
-		t.Parallel()
-		t.Run("happy path", func(t *testing.T) {
-			t.Parallel()
-			lineage := configdomain.NewLineageWith(configdomain.LineageData{
-				one:   main,
-				two:   one,
-				three: two,
-			})
-			have := lineage.LatestAncestor(three, gitdomain.LocalBranchNames{one, two})
-			must.Eq(t, Some(two), have)
-		})
-		t.Run("no candidates", func(t *testing.T) {
-			t.Parallel()
-			lineage := configdomain.NewLineageWith(configdomain.LineageData{
-				one:   main,
-				two:   one,
-				three: two,
-			})
-			have := lineage.LatestAncestor(three, gitdomain.LocalBranchNames{})
-			must.Eq(t, None[gitdomain.LocalBranchName](), have)
-		})
-		t.Run("candidates contains branch", func(t *testing.T) {
-			t.Parallel()
-			lineage := configdomain.NewLineageWith(configdomain.LineageData{
-				one:   main,
-				two:   one,
-				three: two,
-			})
-			have := lineage.LatestAncestor(three, gitdomain.LocalBranchNames{two, three})
-			must.Eq(t, Some(three), have)
-		})
-		t.Run("candidates not in lineage", func(t *testing.T) {
-			t.Parallel()
-			lineage := configdomain.NewLineageWith(configdomain.LineageData{
-				one: main,
-			})
-			have := lineage.LatestAncestor(two, gitdomain.LocalBranchNames{three})
-			must.Eq(t, None[gitdomain.LocalBranchName](), have)
-		})
-	})
-
 	t.Run("Len", func(t *testing.T) {
 		t.Parallel()
 		t.Run("empty", func(t *testing.T) {
@@ -529,7 +510,10 @@ func TestLineage(t *testing.T) {
 			})
 			give := lineage.BranchNames()
 			want := gitdomain.LocalBranchNames{first, second, third, one, two, three}
-			have := lineage.OrderHierarchically(give)
+			have := lineage.OrderHierarchically(give, configdomain.OrderAsc)
+			must.Eq(t, want, have)
+			want = gitdomain.LocalBranchNames{one, two, three, first, second, third}
+			have = lineage.OrderHierarchically(give, configdomain.OrderDesc)
 			must.Eq(t, want, have)
 		})
 		t.Run("single lineage", func(t *testing.T) {
@@ -543,7 +527,7 @@ func TestLineage(t *testing.T) {
 			})
 			give := gitdomain.LocalBranchNames{four, one}
 			want := gitdomain.LocalBranchNames{one, four}
-			have := lineage.OrderHierarchically(give)
+			have := lineage.OrderHierarchically(give, configdomain.OrderAsc)
 			must.Eq(t, want, have)
 		})
 		t.Run("elements out of order", func(t *testing.T) {
@@ -555,22 +539,22 @@ func TestLineage(t *testing.T) {
 			})
 			give := gitdomain.LocalBranchNames{one, two, main, three}
 			want := gitdomain.LocalBranchNames{main, one, two, three}
-			have := lineage.OrderHierarchically(give)
+			have := lineage.OrderHierarchically(give, configdomain.OrderAsc)
 			must.Eq(t, want, have)
 		})
 		t.Run("perennial branches", func(t *testing.T) {
 			t.Parallel()
-			lineage := configdomain.Lineage{}
+			lineage := configdomain.NewLineage()
 			give := gitdomain.LocalBranchNames{one, two, main}
-			want := gitdomain.LocalBranchNames{one, two, main}
-			have := lineage.OrderHierarchically(give)
+			want := gitdomain.LocalBranchNames{main, one, two}
+			have := lineage.OrderHierarchically(give, configdomain.OrderAsc)
 			must.Eq(t, want, have)
 		})
 		t.Run("empty", func(t *testing.T) {
 			t.Parallel()
-			lineage := configdomain.Lineage{}
+			lineage := configdomain.NewLineage()
 			give := gitdomain.LocalBranchNames{}
-			have := lineage.OrderHierarchically(give)
+			have := lineage.OrderHierarchically(give, configdomain.OrderAsc)
 			must.Eq(t, 0, len(have))
 		})
 	})
@@ -588,14 +572,14 @@ func TestLineage(t *testing.T) {
 		})
 		t.Run("main branch", func(t *testing.T) {
 			t.Parallel()
-			lineage := configdomain.Lineage{}
+			lineage := configdomain.NewLineage()
 			have := lineage.Parent(main)
 			want := None[gitdomain.LocalBranchName]()
 			must.EqOp(t, want, have)
 		})
 		t.Run("perennial branch", func(t *testing.T) {
 			t.Parallel()
-			lineage := configdomain.Lineage{}
+			lineage := configdomain.NewLineage()
 			have := lineage.Parent(one)
 			want := None[gitdomain.LocalBranchName]()
 			must.EqOp(t, want, have)
@@ -656,6 +640,34 @@ func TestLineage(t *testing.T) {
 		})
 	})
 
+	t.Run("Root", func(t *testing.T) {
+		t.Parallel()
+		t.Run("stack", func(t *testing.T) {
+			t.Parallel()
+			lineage := configdomain.NewLineageWith(configdomain.LineageData{
+				three: two,
+				two:   one,
+				one:   main,
+			})
+			have := lineage.Root(three)
+			must.Eq(t, main, have)
+		})
+		t.Run("one ancestor", func(t *testing.T) {
+			t.Parallel()
+			lineage := configdomain.NewLineageWith(configdomain.LineageData{
+				one: main,
+			})
+			have := lineage.Root(one)
+			must.Eq(t, main, have)
+		})
+		t.Run("no ancestors", func(t *testing.T) {
+			t.Parallel()
+			lineage := configdomain.NewLineageWith(configdomain.LineageData{})
+			have := lineage.Root(two)
+			must.Eq(t, two, have)
+		})
+	})
+
 	t.Run("Roots", func(t *testing.T) {
 		t.Parallel()
 		t.Run("multiple roots with child branches", func(t *testing.T) {
@@ -684,7 +696,7 @@ func TestLineage(t *testing.T) {
 		})
 		t.Run("empty", func(t *testing.T) {
 			t.Parallel()
-			lineage := configdomain.Lineage{}
+			lineage := configdomain.NewLineage()
 			have := lineage.Roots()
 			want := gitdomain.LocalBranchNames{}
 			must.Eq(t, want, have)
@@ -717,4 +729,46 @@ func TestLineage(t *testing.T) {
 			must.Eq(t, parent, have)
 		})
 	})
+
+	t.Run("YoungestAncestor", func(t *testing.T) {
+		t.Parallel()
+		t.Run("happy path", func(t *testing.T) {
+			t.Parallel()
+			lineage := configdomain.NewLineageWith(configdomain.LineageData{
+				one:   main,
+				two:   one,
+				three: two,
+			})
+			have := lineage.YoungestAncestorWithin(three, gitdomain.LocalBranchNames{one, two})
+			must.True(t, have.EqualSome(two))
+		})
+		t.Run("no candidates", func(t *testing.T) {
+			t.Parallel()
+			lineage := configdomain.NewLineageWith(configdomain.LineageData{
+				one:   main,
+				two:   one,
+				three: two,
+			})
+			have := lineage.YoungestAncestorWithin(three, gitdomain.LocalBranchNames{})
+			must.True(t, have.IsNone())
+		})
+		t.Run("candidates contains branch", func(t *testing.T) {
+			t.Parallel()
+			lineage := configdomain.NewLineageWith(configdomain.LineageData{
+				one:   main,
+				two:   one,
+				three: two,
+			})
+			have := lineage.YoungestAncestorWithin(three, gitdomain.LocalBranchNames{three, two})
+			must.True(t, have.EqualSome(two))
+		})
+		t.Run("candidates not in lineage", func(t *testing.T) {
+			t.Parallel()
+			lineage := configdomain.NewLineageWith(configdomain.LineageData{
+				one: main,
+			})
+			have := lineage.YoungestAncestorWithin(two, gitdomain.LocalBranchNames{three})
+			must.True(t, have.IsNone())
+		})
+	})
 }
