@@ -3,8 +3,8 @@ package configdomain_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v18/internal/config/configdomain"
-	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v22/internal/config/configdomain"
+	"github.com/git-town/git-town/v22/internal/git/gitdomain"
 	"github.com/shoenig/test/must"
 )
 
@@ -13,7 +13,7 @@ func TestPerennialRegex(t *testing.T) {
 
 	t.Run("only characters, no wildcards matches all branch names that contain that phrase", func(t *testing.T) {
 		t.Parallel()
-		perennialRegexOpt, err := configdomain.ParsePerennialRegex("release")
+		perennialRegexOpt, err := configdomain.ParsePerennialRegex("release", "test")
 		must.NoError(t, err)
 		perennialRegex := perennialRegexOpt.GetOrPanic()
 		tests := map[string]bool{
@@ -31,7 +31,7 @@ func TestPerennialRegex(t *testing.T) {
 
 	t.Run("with wildcards", func(t *testing.T) {
 		t.Parallel()
-		perennialRegexOpt, err := configdomain.ParsePerennialRegex("release-.*")
+		perennialRegexOpt, err := configdomain.ParsePerennialRegex("release-.*", "test")
 		must.NoError(t, err)
 		perennialRegex := perennialRegexOpt.GetOrPanic()
 		tests := map[string]bool{
