@@ -1,8 +1,8 @@
 package configdomain
 
 // indicates whether to sync all branches or only the current branch
-type SyncAllBranches bool
+type AllBranches bool
 
-func (self SyncAllBranches) Enabled() bool {
+func (self AllBranches) Enabled() bool {
 	return bool(self)
 }
