@@ -1,6 +1,11 @@
 package configdomain
 
-import . "github.com/git-town/git-town/v18/pkg/prelude"
+import (
+	"fmt"
+
+	"github.com/git-town/git-town/v22/internal/messages"
+	. "github.com/git-town/git-town/v22/pkg/prelude"
+)
 
 // SyncPrototypeStrategy defines legal values for the "sync-prototype-strategy" configuration setting.
 type SyncPrototypeStrategy SyncStrategy
@@ -23,8 +28,11 @@ func NewSyncPrototypeStrategyFromSyncFeatureStrategy(syncFeatureStrategy SyncFea
 	return SyncPrototypeStrategy(syncFeatureStrategy)
 }
 
-func ParseSyncPrototypeStrategy(text string) (Option[SyncPrototypeStrategy], error) {
-	syncStrategyOpt, err := ParseSyncStrategy(text)
+func ParseSyncPrototypeStrategy(value string, source string) (Option[SyncPrototypeStrategy], error) {
+	syncStrategyOpt, err := ParseSyncStrategy(value)
+	if err != nil {
+		return None[SyncPrototypeStrategy](), fmt.Errorf(messages.CannotParse, source, err)
+	}
 	if syncStrategy, has := syncStrategyOpt.Get(); has {
 		return Some(SyncPrototypeStrategy(syncStrategy)), err
 	}
