@@ -1,16 +1,16 @@
 package configdomain
 
 import (
-	"github.com/git-town/git-town/v18/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v18/pkg/prelude"
+	"github.com/git-town/git-town/v22/internal/git/gitdomain"
+	. "github.com/git-town/git-town/v22/pkg/prelude"
 )
 
 // UnvalidatedConfigData is the Git Town configuration as read from disk.
 // It might be lacking essential information in case Git metadata and config files don't contain it.
 // If you need this information, validate it into a ValidatedConfig.
 type UnvalidatedConfigData struct {
-	GitUserEmail Option[GitUserEmail]
-	GitUserName  Option[GitUserName]
+	GitUserEmail Option[gitdomain.GitUserEmail]
+	GitUserName  Option[gitdomain.GitUserName]
 	MainBranch   Option[gitdomain.LocalBranchName]
 }
 
@@ -33,17 +33,6 @@ func (self *UnvalidatedConfigData) PartialBranchType(branch gitdomain.LocalBranc
 
 func (self *UnvalidatedConfigData) ToValidatedConfig(defaults ValidatedConfigData) ValidatedConfigData {
 	return ValidatedConfigData{
-		GitUserEmail: self.GitUserEmail.GetOrElse(defaults.GitUserEmail),
-		GitUserName:  self.GitUserName.GetOrElse(defaults.GitUserName),
-		MainBranch:   self.MainBranch.GetOrElse(defaults.MainBranch),
-	}
-}
-
-// DefaultUnvalidatedConfig provides the default configuration data to use when nothing is configured.
-func DefaultUnvalidatedConfig() UnvalidatedConfigData {
-	return UnvalidatedConfigData{
-		GitUserEmail: None[GitUserEmail](),
-		GitUserName:  None[GitUserName](),
-		MainBranch:   None[gitdomain.LocalBranchName](),
+		MainBranch: self.MainBranch.GetOr(defaults.MainBranch),
 	}
 }
