@@ -3,8 +3,9 @@ package config_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v18/internal/config/configdomain"
-	"github.com/git-town/git-town/v18/test/testruntime"
+	"github.com/git-town/git-town/v22/internal/config/configdomain"
+	"github.com/git-town/git-town/v22/internal/config/gitconfig"
+	"github.com/git-town/git-town/v22/internal/test/testruntime"
 	"github.com/shoenig/test/must"
 )
 
@@ -17,7 +18,7 @@ func TestUnvalidatedConfig(t *testing.T) {
 			t.Parallel()
 			repo := testruntime.CreateGitTown(t)
 			repo.CreateFeatureBranch("branch", "main")
-			repo.Config.Reload()
+			repo.Config.Reload(repo.TestRunner)
 			want := configdomain.NewLineageWith(configdomain.LineageData{
 				"branch": "main",
 			})
@@ -27,9 +28,9 @@ func TestUnvalidatedConfig(t *testing.T) {
 			t.Parallel()
 			repo := testruntime.CreateGitTown(t)
 			repo.CreateBranch("branch", "main")
-			err := repo.Config.NormalConfig.SetBranchTypeOverride(configdomain.BranchTypeContributionBranch, "branch")
+			err := gitconfig.SetBranchTypeOverride(repo.TestRunner, configdomain.BranchTypeContributionBranch, "branch")
 			must.NoError(t, err)
-			repo.Config.Reload()
+			repo.Config.Reload(repo.TestRunner)
 			must.Eq(t, configdomain.BranchTypeContributionBranch, repo.Config.BranchType("branch"))
 		})
 	})
