@@ -5,12 +5,12 @@ import (
 	"os"
 	"testing"
 
-	"github.com/git-town/git-town/v18/internal/config"
-	"github.com/git-town/git-town/v18/internal/config/configdomain"
-	"github.com/git-town/git-town/v18/internal/git/gitdomain"
-	"github.com/git-town/git-town/v18/internal/git/giturl"
-	. "github.com/git-town/git-town/v18/pkg/prelude"
-	"github.com/git-town/git-town/v18/test/testruntime"
+	"github.com/git-town/git-town/v22/internal/config"
+	"github.com/git-town/git-town/v22/internal/config/configdomain"
+	"github.com/git-town/git-town/v22/internal/git/gitdomain"
+	"github.com/git-town/git-town/v22/internal/git/giturl"
+	"github.com/git-town/git-town/v22/internal/test/testruntime"
+	. "github.com/git-town/git-town/v22/pkg/prelude"
 	"github.com/shoenig/test/must"
 )
 
@@ -24,13 +24,8 @@ func TestValidatedConfig(t *testing.T) {
 				MainBranch: "main",
 			},
 			NormalConfig: config.NormalConfig{
-				NormalConfigData: configdomain.NormalConfigData{
-					ContributionBranches: gitdomain.NewLocalBranchNames("contribution"),
-					DefaultBranchType:    configdomain.BranchTypeFeatureBranch,
-					PerennialBranches:    gitdomain.NewLocalBranchNames("perennial-1", "perennial-2"),
-					ObservedBranches:     gitdomain.NewLocalBranchNames("observed"),
-					ParkedBranches:       gitdomain.NewLocalBranchNames("parked"),
-				},
+				UnknownBranchType: configdomain.UnknownBranchType(configdomain.BranchTypeFeatureBranch),
+				PerennialBranches: gitdomain.NewLocalBranchNames("perennial-1", "perennial-2"),
 			},
 		}
 		tests := map[string]bool{
@@ -54,7 +49,7 @@ func TestValidatedConfig(t *testing.T) {
 		repo := testruntime.CreateGitTown(t)
 		repo.CreateFeatureBranch("feature1", "main")
 		repo.CreateFeatureBranch("feature2", "main")
-		repo.Config.Reload()
+		repo.Config.Reload(repo.TestRunner)
 		have := repo.Config.NormalConfig.Lineage
 		want := configdomain.NewLineageWith(configdomain.LineageData{
 			"feature1": "main",
@@ -70,9 +65,7 @@ func TestValidatedConfig(t *testing.T) {
 				MainBranch: "main",
 			},
 			NormalConfig: config.NormalConfig{
-				NormalConfigData: configdomain.NormalConfigData{
-					PerennialBranches: gitdomain.NewLocalBranchNames("perennial-1", "perennial-2"),
-				},
+				PerennialBranches: gitdomain.NewLocalBranchNames("perennial-1", "perennial-2"),
 			},
 		}
 		have := config.MainAndPerennials()
@@ -94,7 +87,7 @@ func TestValidatedConfig(t *testing.T) {
 			repo := testruntime.CreateGitTown(t)
 			os.Setenv("GIT_TOWN_REMOTE", give)
 			defer os.Unsetenv("GIT_TOWN_REMOTE")
-			have, has := repo.Config.NormalConfig.RemoteURL(gitdomain.RemoteOrigin).Get()
+			have, has := repo.Config.NormalConfig.RemoteURL(repo.TestRunner, gitdomain.RemoteOrigin).Get()
 			must.True(t, has)
 			must.EqOp(t, want, have)
 		}
@@ -107,26 +100,18 @@ func TestValidatedConfig(t *testing.T) {
 		feature2 := gitdomain.NewLocalBranchName("feature2")
 		main := gitdomain.NewLocalBranchName("main")
 		observed := gitdomain.NewLocalBranchName("observed")
-		parked := gitdomain.NewLocalBranchName("parked")
 		perennial1 := gitdomain.NewLocalBranchName("perennial-1")
 		perennial2 := gitdomain.NewLocalBranchName("perennial-2")
-		prototype := gitdomain.NewLocalBranchName("prototype")
-		perennialRegexOpt, err := configdomain.ParsePerennialRegex("peren*")
+		perennialRegexOpt, err := configdomain.ParsePerennialRegex("peren*", "test")
 		must.NoError(t, err)
 		config := config.ValidatedConfig{
 			ValidatedConfigData: configdomain.ValidatedConfigData{
 				MainBranch: "main",
 			},
 			NormalConfig: config.NormalConfig{
-				NormalConfigData: configdomain.NormalConfigData{
-					ContributionBranches: gitdomain.LocalBranchNames{contribution},
-					DefaultBranchType:    configdomain.BranchTypeFeatureBranch,
-					ObservedBranches:     gitdomain.LocalBranchNames{observed},
-					ParkedBranches:       gitdomain.LocalBranchNames{parked},
-					PerennialBranches:    gitdomain.LocalBranchNames{perennial1},
-					PerennialRegex:       perennialRegexOpt,
-					PrototypeBranches:    gitdomain.LocalBranchNames{prototype},
-				},
+				UnknownBranchType: configdomain.UnknownBranchType(configdomain.BranchTypeFeatureBranch),
+				PerennialBranches: gitdomain.LocalBranchNames{perennial1},
+				PerennialRegex:    perennialRegexOpt,
 			},
 		}
 		tests := map[*gitdomain.LocalBranchNames]gitdomain.LocalBranchNames{
