@@ -3,7 +3,7 @@ package gitdomain
 import (
 	"fmt"
 
-	. "github.com/git-town/git-town/v18/pkg/prelude"
+	. "github.com/git-town/git-town/v22/pkg/prelude"
 )
 
 // BranchInfo describes the sync status of a branch in relation to its tracking branch.
@@ -41,6 +41,26 @@ func (self BranchInfo) GetLocalOrRemoteName() BranchName {
 	panic("BranchInfo has neither a local nor remote name")
 }
 
+func (self BranchInfo) GetLocalOrRemoteNameAsLocalName() LocalBranchName {
+	if localName, hasLocalName := self.LocalName.Get(); hasLocalName {
+		return localName
+	}
+	if remoteName, hasRemoteName := self.RemoteName.Get(); hasRemoteName {
+		return remoteName.LocalBranchName()
+	}
+	panic("BranchInfo has neither a local nor remote name")
+}
+
+func (self BranchInfo) GetLocalOrRemoteSHA() SHA {
+	if localSHA, has := self.LocalSHA.Get(); has {
+		return localSHA
+	}
+	if remoteSHA, has := self.RemoteSHA.Get(); has {
+		return remoteSHA
+	}
+	panic("BranchInfo has neither a local nor remote SHA")
+}
+
 // provides both the name and SHA of the remote branch
 func (self BranchInfo) GetRemoteBranch() (bool, RemoteBranchName, SHA) {
 	name, hasName := self.RemoteName.Get()
