@@ -3,14 +3,107 @@ package gitdomain_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v18/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v18/pkg/prelude"
+	"github.com/git-town/git-town/v22/internal/git/gitdomain"
+	. "github.com/git-town/git-town/v22/pkg/prelude"
 	"github.com/shoenig/test/must"
 )
 
 func TestBranchInfo(t *testing.T) {
 	t.Parallel()
 
+	t.Run("GetLocalOrRemoteName", func(t *testing.T) {
+		t.Parallel()
+		t.Run("has local and remote name", func(t *testing.T) {
+			t.Parallel()
+			branchInfo := gitdomain.BranchInfo{
+				LocalName:  gitdomain.NewLocalBranchNameOption("branch"),
+				RemoteName: gitdomain.NewRemoteBranchNameOption("origin/branch"),
+			}
+			have := branchInfo.GetLocalOrRemoteName()
+			must.EqOp(t, "branch", have)
+		})
+		t.Run("has only local name", func(t *testing.T) {
+			t.Parallel()
+			branchInfo := gitdomain.BranchInfo{
+				LocalName:  gitdomain.NewLocalBranchNameOption("branch"),
+				RemoteName: None[gitdomain.RemoteBranchName](),
+			}
+			have := branchInfo.GetLocalOrRemoteName()
+			must.EqOp(t, "branch", have)
+		})
+		t.Run("has only remote name", func(t *testing.T) {
+			t.Parallel()
+			branchInfo := gitdomain.BranchInfo{
+				LocalName:  None[gitdomain.LocalBranchName](),
+				RemoteName: gitdomain.NewRemoteBranchNameOption("origin/branch"),
+			}
+			have := branchInfo.GetLocalOrRemoteName()
+			must.EqOp(t, "origin/branch", have)
+		})
+	})
+
+	t.Run("GetLocalOrRemoteNameAsLocalName", func(t *testing.T) {
+		t.Parallel()
+		t.Run("has local and remote name", func(t *testing.T) {
+			t.Parallel()
+			branchInfo := gitdomain.BranchInfo{
+				LocalName:  gitdomain.NewLocalBranchNameOption("branch"),
+				RemoteName: gitdomain.NewRemoteBranchNameOption("origin/branch"),
+			}
+			have := branchInfo.GetLocalOrRemoteNameAsLocalName()
+			must.EqOp(t, "branch", have)
+		})
+		t.Run("has only local name", func(t *testing.T) {
+			t.Parallel()
+			branchInfo := gitdomain.BranchInfo{
+				LocalName:  gitdomain.NewLocalBranchNameOption("branch"),
+				RemoteName: None[gitdomain.RemoteBranchName](),
+			}
+			have := branchInfo.GetLocalOrRemoteNameAsLocalName()
+			must.EqOp(t, "branch", have)
+		})
+		t.Run("has only remote name", func(t *testing.T) {
+			t.Parallel()
+			branchInfo := gitdomain.BranchInfo{
+				LocalName:  None[gitdomain.LocalBranchName](),
+				RemoteName: gitdomain.NewRemoteBranchNameOption("origin/branch"),
+			}
+			have := branchInfo.GetLocalOrRemoteNameAsLocalName()
+			must.EqOp(t, "branch", have)
+		})
+	})
+
+	t.Run("GetLocalOrRemoteSHA", func(t *testing.T) {
+		t.Parallel()
+		t.Run("has local and remote SHA", func(t *testing.T) {
+			t.Parallel()
+			branchInfo := gitdomain.BranchInfo{
+				LocalSHA:  Some(gitdomain.NewSHA("111111")),
+				RemoteSHA: Some(gitdomain.NewSHA("111111")),
+			}
+			have := branchInfo.GetLocalOrRemoteSHA()
+			must.EqOp(t, "111111", have)
+		})
+		t.Run("has only local SHA", func(t *testing.T) {
+			t.Parallel()
+			branchInfo := gitdomain.BranchInfo{
+				LocalSHA:  Some(gitdomain.NewSHA("111111")),
+				RemoteSHA: None[gitdomain.SHA](),
+			}
+			have := branchInfo.GetLocalOrRemoteSHA()
+			must.EqOp(t, "111111", have)
+		})
+		t.Run("has only remote SHA", func(t *testing.T) {
+			t.Parallel()
+			branchInfo := gitdomain.BranchInfo{
+				LocalSHA:  None[gitdomain.SHA](),
+				RemoteSHA: Some(gitdomain.NewSHA("111111")),
+			}
+			have := branchInfo.GetLocalOrRemoteSHA()
+			must.EqOp(t, "111111", have)
+		})
+	})
+
 	t.Run("HasLocalBranch", func(t *testing.T) {
 		t.Parallel()
 		t.Run("is a local branch", func(t *testing.T) {
@@ -76,7 +169,7 @@ func TestBranchInfo(t *testing.T) {
 		t.Run("has only a local branch", func(t *testing.T) {
 			t.Parallel()
 			give := gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("branch-1")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("branch-1"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusLocalOnly,
 				RemoteName: None[gitdomain.RemoteBranchName](),
@@ -87,7 +180,7 @@ func TestBranchInfo(t *testing.T) {
 		t.Run("is omnibranch", func(t *testing.T) {
 			t.Parallel()
 			give := gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("branch-1")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("branch-1"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusUpToDate,
 				RemoteName: Some(gitdomain.NewRemoteBranchName("origin/branch-1")),
@@ -135,7 +228,7 @@ func TestBranchInfo(t *testing.T) {
 		t.Run("has only a local branch", func(t *testing.T) {
 			t.Parallel()
 			give := gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("branch-1")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("branch-1"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusLocalOnly,
 				RemoteName: None[gitdomain.RemoteBranchName](),
@@ -146,7 +239,7 @@ func TestBranchInfo(t *testing.T) {
 		t.Run("is omnibranch", func(t *testing.T) {
 			t.Parallel()
 			give := gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("branch-1")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("branch-1"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusUpToDate,
 				RemoteName: Some(gitdomain.NewRemoteBranchName("origin/branch-1")),
@@ -190,7 +283,7 @@ func TestBranchInfo(t *testing.T) {
 			branch1 := gitdomain.NewRemoteBranchName("origin/branch-1")
 			sha1 := gitdomain.NewSHA("111111")
 			branchInfo := gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("branch-1")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("branch-1"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusUpToDate,
 				RemoteName: Some(gitdomain.NewRemoteBranchName("origin/branch-1")),
@@ -204,7 +297,7 @@ func TestBranchInfo(t *testing.T) {
 		t.Run("has only a local branch", func(t *testing.T) {
 			t.Parallel()
 			branchInfo := gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("branch-1")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("branch-1"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusLocalOnly,
 				RemoteName: None[gitdomain.RemoteBranchName](),
@@ -232,7 +325,7 @@ func TestBranchInfo(t *testing.T) {
 		t.Run("has both branches", func(t *testing.T) {
 			t.Parallel()
 			give := gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("branch-1")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("branch-1"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusUpToDate,
 				RemoteName: Some(gitdomain.NewRemoteBranchName("origin/branch-1")),
@@ -243,7 +336,7 @@ func TestBranchInfo(t *testing.T) {
 		t.Run("has local branch", func(t *testing.T) {
 			t.Parallel()
 			give := gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("branch-1")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("branch-1"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusLocalOnly,
 				RemoteName: None[gitdomain.RemoteBranchName](),
@@ -305,6 +398,19 @@ func TestBranchInfo(t *testing.T) {
 			must.False(t, isLocal)
 			must.Eq(t, branchName, haveBranchName)
 		})
+		t.Run("remote-only branch", func(t *testing.T) {
+			t.Parallel()
+			branchInfo := gitdomain.BranchInfo{
+				LocalName:  None[gitdomain.LocalBranchName](),
+				LocalSHA:   None[gitdomain.SHA](),
+				RemoteName: Some(gitdomain.NewRemoteBranchName("origin/foo")),
+				RemoteSHA:  Some(gitdomain.SHA("111111")),
+				SyncStatus: gitdomain.SyncStatusUpToDate,
+			}
+			isLocal, haveBranchName := branchInfo.IsLocalOnlyBranch()
+			must.False(t, isLocal)
+			must.Eq(t, "", haveBranchName)
+		})
 	})
 
 	t.Run("IsOmniBranch", func(t *testing.T) {
@@ -328,7 +434,7 @@ func TestBranchInfo(t *testing.T) {
 		t.Run("not an omnibranch", func(t *testing.T) {
 			t.Parallel()
 			give := gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("branch-1")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("branch-1"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusNotInSync,
 				RemoteName: Some(gitdomain.NewRemoteBranchName("origin/branch-1")),
