@@ -3,7 +3,7 @@ package gitdomain
 import (
 	"fmt"
 
-	. "github.com/git-town/git-town/v18/pkg/prelude"
+	. "github.com/git-town/git-town/v22/pkg/prelude"
 )
 
 // BranchInfos contains the BranchInfos for all branches in a repo.
@@ -138,8 +138,17 @@ func (self BranchInfos) LocalBranchesWithDeletedTrackingBranches() BranchInfos {
 	return result
 }
 
-// Names provides the names of all local branches in this BranchesSyncStatus instance.
-func (self BranchInfos) Names() LocalBranchNames {
+// NamesAllBranches provides the local names for all branches in this BranchesSyncStatus instance.
+func (self BranchInfos) NamesAllBranches() LocalBranchNames {
+	result := make(LocalBranchNames, 0, len(self))
+	for _, bi := range self {
+		result = append(result, bi.GetLocalOrRemoteNameAsLocalName())
+	}
+	return result
+}
+
+// NamesLocalBranches provides the names of all local branches in this BranchesSyncStatus instance.
+func (self BranchInfos) NamesLocalBranches() LocalBranchNames {
 	result := make(LocalBranchNames, 0, len(self))
 	for _, bi := range self {
 		if localName, hasLocalName := bi.LocalName.Get(); hasLocalName {
@@ -178,6 +187,14 @@ func (self BranchInfos) Select(remote Remote, names ...LocalBranchName) (result
 	return result, nonExisting
 }
 
+func (self BranchInfos) String() string {
+	result := "BranchInfos:\n"
+	for _, bi := range self {
+		result += bi.String() + "\n"
+	}
+	return result
+}
+
 func (self BranchInfos) UpdateLocalSHA(branch LocalBranchName, sha SHA) error {
 	for b := range self {
 		if localName, hasLocalName := self[b].LocalName.Get(); hasLocalName {
