@@ -3,8 +3,8 @@ package gitdomain_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v18/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v18/pkg/prelude"
+	"github.com/git-town/git-town/v22/internal/git/gitdomain"
+	. "github.com/git-town/git-town/v22/pkg/prelude"
 	"github.com/shoenig/test/must"
 )
 
@@ -17,11 +17,11 @@ func TestBranchInfos(t *testing.T) {
 			t.Parallel()
 			branchInfos := gitdomain.BranchInfos{
 				{
-					LocalName:  Some(gitdomain.NewLocalBranchName("branch-1")),
+					LocalName:  gitdomain.NewLocalBranchNameOption("branch-1"),
 					SyncStatus: gitdomain.SyncStatusLocalOnly,
 				},
 				{
-					LocalName:  Some(gitdomain.NewLocalBranchName("branch-2")),
+					LocalName:  gitdomain.NewLocalBranchNameOption("branch-2"),
 					SyncStatus: gitdomain.SyncStatusOtherWorktree,
 				},
 			}
@@ -32,7 +32,7 @@ func TestBranchInfos(t *testing.T) {
 			t.Parallel()
 			branchInfos := gitdomain.BranchInfos{
 				{
-					LocalName:  Some(gitdomain.NewLocalBranchName("branch-1")),
+					LocalName:  gitdomain.NewLocalBranchNameOption("branch-1"),
 					SyncStatus: gitdomain.SyncStatusLocalOnly,
 				},
 			}
@@ -68,7 +68,7 @@ func TestBranchInfos(t *testing.T) {
 		t.Run("has a local branch with matching tracking branch", func(t *testing.T) {
 			t.Parallel()
 			branch := gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("two")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("two"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusUpToDate,
 				RemoteName: Some(gitdomain.NewRemoteBranchName("origin/two")),
@@ -82,7 +82,7 @@ func TestBranchInfos(t *testing.T) {
 		t.Run("has a local branch with the given name", func(t *testing.T) {
 			t.Parallel()
 			bs := gitdomain.BranchInfos{gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("kg/one")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("kg/one"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusLocalOnly,
 				RemoteName: None[gitdomain.RemoteBranchName](),
@@ -149,7 +149,7 @@ func TestBranchInfos(t *testing.T) {
 			t.Parallel()
 			bis := gitdomain.BranchInfos{
 				gitdomain.BranchInfo{
-					LocalName:  Some(gitdomain.NewLocalBranchName("branch-1")),
+					LocalName:  gitdomain.NewLocalBranchNameOption("branch-1"),
 					LocalSHA:   Some(gitdomain.NewSHA("111111")),
 					SyncStatus: gitdomain.SyncStatusLocalOnly,
 					RemoteName: None[gitdomain.RemoteBranchName](),
@@ -157,7 +157,7 @@ func TestBranchInfos(t *testing.T) {
 				},
 			}
 			give := gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("branch-1")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("branch-1"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusLocalOnly,
 				RemoteName: None[gitdomain.RemoteBranchName](),
@@ -197,7 +197,7 @@ func TestBranchInfos(t *testing.T) {
 			t.Parallel()
 			bs := gitdomain.BranchInfos{
 				gitdomain.BranchInfo{
-					LocalName:  Some(gitdomain.NewLocalBranchName("one")),
+					LocalName:  gitdomain.NewLocalBranchNameOption("one"),
 					LocalSHA:   Some(gitdomain.NewSHA("111111")),
 					SyncStatus: gitdomain.SyncStatusLocalOnly,
 					RemoteName: None[gitdomain.RemoteBranchName](),
@@ -223,7 +223,7 @@ func TestBranchInfos(t *testing.T) {
 			t.Parallel()
 			bs := gitdomain.BranchInfos{
 				gitdomain.BranchInfo{
-					LocalName:  Some(gitdomain.NewLocalBranchName("two")),
+					LocalName:  gitdomain.NewLocalBranchNameOption("two"),
 					LocalSHA:   Some(gitdomain.NewSHA("111111")),
 					SyncStatus: gitdomain.SyncStatusUpToDate,
 					RemoteName: Some(gitdomain.NewRemoteBranchName("origin/one")),
@@ -240,7 +240,7 @@ func TestBranchInfos(t *testing.T) {
 			t.Parallel()
 			bs := gitdomain.BranchInfos{
 				gitdomain.BranchInfo{
-					LocalName:  Some(gitdomain.NewLocalBranchName("two")),
+					LocalName:  gitdomain.NewLocalBranchNameOption("two"),
 					LocalSHA:   Some(gitdomain.NewSHA("111111")),
 					SyncStatus: gitdomain.SyncStatusUpToDate,
 					RemoteName: Some(gitdomain.NewRemoteBranchName("origin/one")),
@@ -266,7 +266,7 @@ func TestBranchInfos(t *testing.T) {
 			t.Parallel()
 			bs := gitdomain.BranchInfos{
 				gitdomain.BranchInfo{
-					LocalName:  Some(gitdomain.NewLocalBranchName("one")),
+					LocalName:  gitdomain.NewLocalBranchNameOption("one"),
 					LocalSHA:   Some(gitdomain.NewSHA("111111")),
 					SyncStatus: gitdomain.SyncStatusLocalOnly,
 					RemoteName: None[gitdomain.RemoteBranchName](),
@@ -281,28 +281,28 @@ func TestBranchInfos(t *testing.T) {
 		t.Parallel()
 		bs := gitdomain.BranchInfos{
 			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("up-to-date")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("up-to-date"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusUpToDate,
 				RemoteName: Some(gitdomain.NewRemoteBranchName("origin/up-to-date")),
 				RemoteSHA:  Some(gitdomain.NewSHA("111111")),
 			},
 			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("ahead")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("ahead"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusNotInSync,
 				RemoteName: Some(gitdomain.NewRemoteBranchName("origin/ahead")),
 				RemoteSHA:  Some(gitdomain.NewSHA("222222")),
 			},
 			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("behind")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("behind"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusNotInSync,
 				RemoteName: Some(gitdomain.NewRemoteBranchName("origin/behind")),
 				RemoteSHA:  Some(gitdomain.NewSHA("222222")),
 			},
 			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("local-only")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("local-only"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusLocalOnly,
 				RemoteName: None[gitdomain.RemoteBranchName](),
@@ -316,14 +316,14 @@ func TestBranchInfos(t *testing.T) {
 				RemoteSHA:  Some(gitdomain.NewSHA("111111")),
 			},
 			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("deleted-at-remote")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("deleted-at-remote"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusDeletedAtRemote,
 				RemoteName: None[gitdomain.RemoteBranchName](),
 				RemoteSHA:  None[gitdomain.SHA](),
 			},
 		}
-		have := bs.LocalBranches().Names()
+		have := bs.LocalBranches().NamesLocalBranches()
 		want := gitdomain.NewLocalBranchNames("up-to-date", "ahead", "behind", "local-only", "deleted-at-remote")
 		must.Eq(t, want, have)
 	})
@@ -332,28 +332,28 @@ func TestBranchInfos(t *testing.T) {
 		t.Parallel()
 		bs := gitdomain.BranchInfos{
 			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("up-to-date")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("up-to-date"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusUpToDate,
 				RemoteName: Some(gitdomain.NewRemoteBranchName("origin/up-to-date")),
 				RemoteSHA:  Some(gitdomain.NewSHA("111111")),
 			},
 			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("ahead")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("ahead"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusNotInSync,
 				RemoteName: Some(gitdomain.NewRemoteBranchName("origin/ahead")),
 				RemoteSHA:  Some(gitdomain.NewSHA("222222")),
 			},
 			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("behind")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("behind"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusNotInSync,
 				RemoteName: Some(gitdomain.NewRemoteBranchName("origin/behind")),
 				RemoteSHA:  Some(gitdomain.NewSHA("222222")),
 			},
 			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("local-only")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("local-only"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusLocalOnly,
 				RemoteName: None[gitdomain.RemoteBranchName](),
@@ -367,14 +367,14 @@ func TestBranchInfos(t *testing.T) {
 				RemoteSHA:  Some(gitdomain.NewSHA("111111")),
 			},
 			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("deleted-at-remote")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("deleted-at-remote"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusDeletedAtRemote,
 				RemoteName: None[gitdomain.RemoteBranchName](),
 				RemoteSHA:  None[gitdomain.SHA](),
 			},
 		}
-		have := bs.LocalBranchesWithDeletedTrackingBranches().Names()
+		have := bs.LocalBranchesWithDeletedTrackingBranches().NamesLocalBranches()
 		want := gitdomain.NewLocalBranchNames("deleted-at-remote")
 		must.Eq(t, want, have)
 	})
@@ -382,6 +382,7 @@ func TestBranchInfos(t *testing.T) {
 	t.Run("LookupLocalBranch", func(t *testing.T) {
 		t.Parallel()
 		t.Run("local branch with matching name", func(t *testing.T) {
+			t.Parallel()
 			branchOne := gitdomain.NewLocalBranchName("one")
 			branchInfos := gitdomain.BranchInfos{
 				gitdomain.BranchInfo{
@@ -397,6 +398,7 @@ func TestBranchInfos(t *testing.T) {
 			must.EqOp(t, branchOne, branchInfo.LocalName.GetOrPanic())
 		})
 		t.Run("remote branch with matching name", func(t *testing.T) {
+			t.Parallel()
 			branchInfos := gitdomain.BranchInfos{
 				gitdomain.BranchInfo{
 					LocalName:  None[gitdomain.LocalBranchName](),
@@ -411,18 +413,18 @@ func TestBranchInfos(t *testing.T) {
 		})
 	})
 
-	t.Run("Names", func(t *testing.T) {
+	t.Run("NamesAllBranches", func(t *testing.T) {
 		t.Parallel()
 		bs := gitdomain.BranchInfos{
 			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("one")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("one"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusLocalOnly,
 				RemoteName: None[gitdomain.RemoteBranchName](),
 				RemoteSHA:  None[gitdomain.SHA](),
 			},
 			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("two")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("two"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusLocalOnly,
 				RemoteName: None[gitdomain.RemoteBranchName](),
@@ -436,7 +438,37 @@ func TestBranchInfos(t *testing.T) {
 				RemoteSHA:  Some(gitdomain.NewSHA("111111")),
 			},
 		}
-		have := bs.Names()
+		have := bs.NamesAllBranches()
+		want := gitdomain.NewLocalBranchNames("one", "two", "three")
+		must.Eq(t, want, have)
+	})
+
+	t.Run("NamesLocalBranches", func(t *testing.T) {
+		t.Parallel()
+		bs := gitdomain.BranchInfos{
+			gitdomain.BranchInfo{
+				LocalName:  gitdomain.NewLocalBranchNameOption("one"),
+				LocalSHA:   Some(gitdomain.NewSHA("111111")),
+				SyncStatus: gitdomain.SyncStatusLocalOnly,
+				RemoteName: None[gitdomain.RemoteBranchName](),
+				RemoteSHA:  None[gitdomain.SHA](),
+			},
+			gitdomain.BranchInfo{
+				LocalName:  gitdomain.NewLocalBranchNameOption("two"),
+				LocalSHA:   Some(gitdomain.NewSHA("111111")),
+				SyncStatus: gitdomain.SyncStatusLocalOnly,
+				RemoteName: None[gitdomain.RemoteBranchName](),
+				RemoteSHA:  None[gitdomain.SHA](),
+			},
+			gitdomain.BranchInfo{
+				LocalName:  None[gitdomain.LocalBranchName](),
+				LocalSHA:   None[gitdomain.SHA](),
+				SyncStatus: gitdomain.SyncStatusRemoteOnly,
+				RemoteName: Some(gitdomain.NewRemoteBranchName("origin/three")),
+				RemoteSHA:  Some(gitdomain.NewSHA("111111")),
+			},
+		}
+		have := bs.NamesLocalBranches()
 		want := gitdomain.NewLocalBranchNames("one", "two")
 		must.Eq(t, want, have)
 	})
@@ -444,16 +476,17 @@ func TestBranchInfos(t *testing.T) {
 	t.Run("Remove", func(t *testing.T) {
 		t.Parallel()
 		t.Run("contains the removed element", func(t *testing.T) {
+			t.Parallel()
 			bs := gitdomain.BranchInfos{
 				gitdomain.BranchInfo{
-					LocalName:  Some(gitdomain.NewLocalBranchName("one")),
+					LocalName:  gitdomain.NewLocalBranchNameOption("one"),
 					LocalSHA:   Some(gitdomain.NewSHA("111111")),
 					SyncStatus: gitdomain.SyncStatusLocalOnly,
 					RemoteName: None[gitdomain.RemoteBranchName](),
 					RemoteSHA:  None[gitdomain.SHA](),
 				},
 				gitdomain.BranchInfo{
-					LocalName:  Some(gitdomain.NewLocalBranchName("two")),
+					LocalName:  gitdomain.NewLocalBranchNameOption("two"),
 					LocalSHA:   Some(gitdomain.NewSHA("111111")),
 					SyncStatus: gitdomain.SyncStatusLocalOnly,
 					RemoteName: None[gitdomain.RemoteBranchName](),
@@ -463,7 +496,7 @@ func TestBranchInfos(t *testing.T) {
 			have := bs.Remove(gitdomain.NewLocalBranchName("two"))
 			want := gitdomain.BranchInfos{
 				gitdomain.BranchInfo{
-					LocalName:  Some(gitdomain.NewLocalBranchName("one")),
+					LocalName:  gitdomain.NewLocalBranchNameOption("one"),
 					LocalSHA:   Some(gitdomain.NewSHA("111111")),
 					SyncStatus: gitdomain.SyncStatusLocalOnly,
 					RemoteName: None[gitdomain.RemoteBranchName](),
@@ -478,28 +511,28 @@ func TestBranchInfos(t *testing.T) {
 		t.Parallel()
 		bs := gitdomain.BranchInfos{
 			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("one")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("one"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusLocalOnly,
 				RemoteName: None[gitdomain.RemoteBranchName](),
 				RemoteSHA:  None[gitdomain.SHA](),
 			},
 			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("two")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("two"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusLocalOnly,
 				RemoteName: None[gitdomain.RemoteBranchName](),
 				RemoteSHA:  None[gitdomain.SHA](),
 			},
 			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("three")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("three"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusLocalOnly,
 				RemoteName: None[gitdomain.RemoteBranchName](),
 				RemoteSHA:  None[gitdomain.SHA](),
 			},
 			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("four")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("four"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusLocalOnly,
 				RemoteName: None[gitdomain.RemoteBranchName](),
@@ -509,14 +542,14 @@ func TestBranchInfos(t *testing.T) {
 		have, nonExisting := bs.Select(gitdomain.RemoteOrigin, "one", "three")
 		want := gitdomain.BranchInfos{
 			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("one")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("one"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusLocalOnly,
 				RemoteName: None[gitdomain.RemoteBranchName](),
 				RemoteSHA:  None[gitdomain.SHA](),
 			},
 			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("three")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("three"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusLocalOnly,
 				RemoteName: None[gitdomain.RemoteBranchName](),
@@ -531,14 +564,14 @@ func TestBranchInfos(t *testing.T) {
 		t.Parallel()
 		bs := gitdomain.BranchInfos{
 			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("one")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("one"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusLocalOnly,
 				RemoteName: None[gitdomain.RemoteBranchName](),
 				RemoteSHA:  None[gitdomain.SHA](),
 			},
 			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("two")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("two"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusLocalOnly,
 				RemoteName: None[gitdomain.RemoteBranchName](),
@@ -548,14 +581,14 @@ func TestBranchInfos(t *testing.T) {
 		have := bs.Remove(gitdomain.NewLocalBranchName("zonk"))
 		want := gitdomain.BranchInfos{
 			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("one")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("one"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusLocalOnly,
 				RemoteName: None[gitdomain.RemoteBranchName](),
 				RemoteSHA:  None[gitdomain.SHA](),
 			},
 			gitdomain.BranchInfo{
-				LocalName:  Some(gitdomain.NewLocalBranchName("two")),
+				LocalName:  gitdomain.NewLocalBranchNameOption("two"),
 				LocalSHA:   Some(gitdomain.NewSHA("111111")),
 				SyncStatus: gitdomain.SyncStatusLocalOnly,
 				RemoteName: None[gitdomain.RemoteBranchName](),
