@@ -4,8 +4,8 @@ import (
 	"encoding/json"
 	"testing"
 
-	"github.com/git-town/git-town/v18/internal/git/gitdomain"
-	"github.com/git-town/git-town/v18/test/asserts"
+	"github.com/git-town/git-town/v22/internal/git/gitdomain"
+	"github.com/git-town/git-town/v22/pkg/asserts"
 	"github.com/shoenig/test/must"
 )
 
@@ -53,15 +53,28 @@ func TestBranchName(t *testing.T) {
 	t.Run("NewBranchName and String", func(t *testing.T) {
 		t.Parallel()
 		t.Run("normal branch name", func(t *testing.T) {
+			t.Parallel()
 			branchName := gitdomain.NewBranchName("branch-1")
 			must.EqOp(t, "branch-1", branchName.String())
 		})
 		t.Run("does not allow empty branch names", func(t *testing.T) {
+			t.Parallel()
 			defer asserts.Paniced(t)
 			gitdomain.NewBranchName("")
 		})
 	})
 
+	t.Run("RefName", func(t *testing.T) {
+		t.Parallel()
+		tests := map[gitdomain.BranchName]string{
+			"main":        "refs/heads/main",
+			"origin/main": "origin/main",
+		}
+		for give, want := range tests {
+			must.EqOp(t, want, give.RefName())
+		}
+	})
+
 	t.Run("RemoteName", func(t *testing.T) {
 		t.Run("local branch name", func(t *testing.T) {
 			t.Parallel()
