@@ -1,5 +1,7 @@
 package gitdomain
 
+import . "github.com/git-town/git-town/v22/pkg/prelude"
+
 type Commits []Commit
 
 // ContainsSHA indicates whether this commits list contains a commit with the given SHA.
@@ -12,6 +14,15 @@ func (self Commits) ContainsSHA(sha SHA) bool {
 	return false
 }
 
+func (self Commits) FindByCommitMessage(message CommitMessage) Option[Commit] {
+	for _, commit := range self {
+		if commit.Message == message {
+			return Some(commit)
+		}
+	}
+	return None[Commit]()
+}
+
 func (self Commits) Messages() CommitMessages {
 	result := make(CommitMessages, len(self))
 	for c, commit := range self {
