@@ -2,10 +2,9 @@ package gitdomain
 
 import (
 	"slices"
-	"sort"
 	"strings"
 
-	"github.com/git-town/git-town/v18/internal/gohacks/slice"
+	"github.com/git-town/git-town/v22/internal/gohacks/slice"
 )
 
 type LocalBranchNames []LocalBranchName
@@ -33,8 +32,10 @@ func ParseLocalBranchNames(names string) LocalBranchNames {
 }
 
 // AppendAllMissing provides a LocalBranchNames list consisting of the sum of this and elements of other list that aren't in this list.
-func (self LocalBranchNames) AppendAllMissing(others ...LocalBranchName) LocalBranchNames {
-	return slice.AppendAllMissing(self, others...)
+func (self LocalBranchNames) AppendAllMissing(others LocalBranchNames) LocalBranchNames {
+	missing := slice.FindAllMissing(self, others)
+	slice.NaturalSort(missing)
+	return append(self, missing...)
 }
 
 func (self LocalBranchNames) BranchNames() []BranchName {
@@ -83,26 +84,6 @@ func (self LocalBranchNames) Remove(toRemove ...LocalBranchName) LocalBranchName
 	return result
 }
 
-// RemoveWorktreeMarkers removes the workspace markers from the branch names in this list.
-func (self LocalBranchNames) RemoveWorktreeMarkers() LocalBranchNames {
-	result := make(LocalBranchNames, len(self))
-	for b, branch := range self {
-		if strings.HasPrefix(branch.String(), "+ ") {
-			result[b] = branch[2:]
-		} else {
-			result[b] = branch
-		}
-	}
-	return result
-}
-
-// Sort orders the branches in this collection alphabetically.
-func (self LocalBranchNames) Sort() {
-	sort.Slice(self, func(a, b int) bool {
-		return self[a] < self[b]
-	})
-}
-
 func (self LocalBranchNames) String() string {
 	if self == nil {
 		return ""
