@@ -3,6 +3,8 @@ package gitdomain
 import (
 	"fmt"
 	"strings"
+
+	. "github.com/git-town/git-town/v22/pkg/prelude"
 )
 
 // RemoteBranchName is the name of a remote branch, e.g. "origin/foo".
@@ -15,6 +17,13 @@ func NewRemoteBranchName(id string) RemoteBranchName {
 	return RemoteBranchName(id)
 }
 
+func NewRemoteBranchNameOption(id string) Option[RemoteBranchName] {
+	if isValidRemoteBranchName(id) {
+		return Some(NewRemoteBranchName(id))
+	}
+	return None[RemoteBranchName]()
+}
+
 func isValidRemoteBranchName(value string) bool {
 	if len(value) < 3 {
 		return false
@@ -37,8 +46,8 @@ func (self RemoteBranchName) LocalBranchName() LocalBranchName {
 }
 
 func (self RemoteBranchName) Parts() (Remote, LocalBranchName) {
-	parts := strings.SplitN(string(self), "/", 2)
-	return Remote(parts[0]), NewLocalBranchName(parts[1])
+	remoteName, branchname, _ := strings.Cut(string(self), "/")
+	return Remote(remoteName), NewLocalBranchName(branchname)
 }
 
 func (self RemoteBranchName) Remote() Remote {
